@@ -1,4 +1,4 @@
-from handler import GELFHandler, WAN_CHUNK, LAN_CHUNK
+from graypy.handler import GELFHandler, WAN_CHUNK, LAN_CHUNK
 try:
     from rabbitmq import GELFRabbitHandler, ExcludeFilter
 except ImportError:
