@@ -52,7 +52,7 @@ class GELFHandler(DatagramHandler):
         message_dict = make_message_dict(
             record, self.debugging_fields, self.extra_fields, self.fqdn, 
 	    self.localname, self.facility)
-        return zlib.compress(json.dumps(message_dict))
+        return zlib.compress(json.dumps(message_dict).encode('utf-8'))
 
 
 class ChunkedGELF(object):
@@ -90,7 +90,7 @@ def make_message_dict(record, debugging_fields, extra_fields, fqdn, localname, f
     fields = {'version': "1.0",
         'host': host,
         'short_message': record.getMessage(),
-        'full_message': get_full_message(record.exc_info),
+        'full_message': get_full_message(record.exc_info, record.getMessage()),
         'timestamp': record.created,
         'level': SYSLOG_LEVELS.get(record.levelno, record.levelno),
         'facility': facility or record.name,
@@ -98,7 +98,7 @@ def make_message_dict(record, debugging_fields, extra_fields, fqdn, localname, f
 
     if facility is not None:
         fields.update({
-            'logger': record.name
+            '_logger': record.name
         })
 
     if debugging_fields:
@@ -126,8 +126,8 @@ SYSLOG_LEVELS = {
 }
 
 
-def get_full_message(exc_info):
-    return '\n'.join(traceback.format_exception(*exc_info)) if exc_info else ''
+def get_full_message(exc_info, message):
+    return '\n'.join(traceback.format_exception(*exc_info)) if exc_info else message
 
 
 def add_extra_fields(message_dict, record):
@@ -144,6 +144,9 @@ def add_extra_fields(message_dict, record):
 
     for key, value in record.__dict__.items():
         if key not in skip_list and not key.startswith('_'):
-            message_dict['_%s' % key] = repr(value)
+            if isinstance(value, (basestring, int, long, float)):
+                message_dict['_%s' % key] = value
+            else:
+                message_dict['_%s' % key] = repr(value)
 
     return message_dict
